/*
** Module   : LabelImpl.java
** Abstract :
**
** Copyright (c) 2011-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20111126          Extracted from Label
** 002 SIY 20111221          Fixed constructor visibility.
** 003 EVL 20140528          Fix for displaying the labels for hidden widgets in a frame.  It is
**                           possible to have only horizontal line to display without label text.
*/

package com.goldencode.p2j.ui.chui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.format.*;

/**
 * CHUI-specific portion of Label.
 */
@SuppressWarnings("unchecked")
public class LabelImpl
extends Label
{
   /**
    * Constructs label with given text.
    * 
    * @param   text
    *          Initial text.
    */
   LabelImpl(String text)
   {
      super(text);
   }

   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   cfg
    *          Configuration data.
    */
   public LabelImpl(ComponentConfig cfg)
   {
      super(cfg);
   }

   /**
    * Create a copy of the label.
    * 
    * @param   label
    *          Label to copy parameters from.
    */
   LabelImpl(Label label)
   {
      super(label);
   }
   
   /**
    * Draws text. Screen value is left justified or padded to the right bound
    * with spaces. Non first lines are filled with spaces.
    */
   @Override
   public void draw()
   {
      if (parent() == null)
         return;
      
      Dimension actualSize = dimension();
      Point origin = screenLocation();
      OutputManager screen = screen();

      Color clr = UiUtils.getDcolor(this);

      String[] values = name().split("\n");
      String spaces = DisplayFormat.generateSpaces(actualSize.width);
      
      screen.at(origin);

      for (int i = 0; i < actualSize.height; i++, origin.y++)
      {
         String screenValue;
         
         if (i < values.length && !emptyMode)
            screenValue = DisplayFormat.formatScreenValue(values[i],
                                                          actualSize.width,
                                                          0,
                                                          rightAligned,
                                                          rightAligned);
         else
            screenValue = spaces;

         if (i == (actualSize.height - 1) && underlined)
         {
            // draw the separator line
            screen.at(origin).hLine(actualSize.width, clr);
         }
         else if (!emptyMode)// fix for UNLESS-HIDDEN option
         {
            screen.at(origin.offset(offset, 0)).append(screenValue, clr);
         }
      }
      
      if (disableEmptyMode)
         emptyMode = false;
      
      disableEmptyMode = false;
   }

   /**
    * Sets position of terminal's cursor. Really does nothing because this
    * widget will never get an input focus.
    */
   @Override
   public void drawCaret()
   {
   }
}
